Aspen is a Python web framework. Simplates are the main attraction.

Installation, Testing, and License
==================================

``aspen`` is available on `GitHub`_ and on `PyPI`_::

    $ pip install aspen

We test against 64-bit Python 2.7 on Linux: |travis|

And we test against 32- and 64-bit Python 2.7 on Windows: |appveyor|

``aspen`` is MIT-licensed.


.. _GitHub: https://github.com/gratipay/aspen.py
.. _PyPI: https://pypi.python.org/pypi/aspen
.. |travis| image:: https://img.shields.io/travis/gratipay/aspen.py/master.svg
   :target: https://travis-ci.org/gratipay/aspen.py
   :alt: Linux build status
.. |appveyor| image:: https://img.shields.io/appveyor/ci/gratipay/aspen-py/master.svg
   :target: https://ci.appveyor.com/project/gratipay/aspen-py
   :alt: Windows build status


Documentation and further information
=====================================

on the main `site`_ : http://aspen.io/

.. _site: http://aspen.io/

